"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const imperative_1 = require("@zowe/imperative");
const zos_files_for_zowe_sdk_1 = require("@zowe/zos-files-for-zowe-sdk");
const ZosFilesBase_handler_1 = require("../../ZosFilesBase.handler");
/**
 * Handler to view a data set's content
 * @export
 */
class LocalfileDatasetHandler extends ZosFilesBase_handler_1.ZosFilesBaseHandler {
    processWithSession(commandParameters, session) {
        return __awaiter(this, void 0, void 0, function* () {
            const task = {
                percentComplete: 0,
                statusMessage: "Retrieving local file",
                stageName: imperative_1.TaskStage.IN_PROGRESS
            };
            commandParameters.response.progress.startBar({ task });
            let localFile;
            // resolving to full path if local path passed is not absolute
            if (path.isAbsolute(commandParameters.arguments.localFilePath)) {
                localFile = commandParameters.arguments.localFilePath;
            }
            else {
                localFile = path.resolve(commandParameters.arguments.localFilePath);
            }
            // check if the path given is of a file or not
            try {
                if (!fs.lstatSync(localFile).isFile()) {
                    throw new imperative_1.ImperativeError({
                        msg: 'Path given is not of a file, do recheck your path again'
                    });
                }
            }
            catch (error) {
                if (error instanceof imperative_1.ImperativeError)
                    throw error;
                throw new imperative_1.ImperativeError({
                    msg: 'Path not found. Please check the path and try again'
                });
            }
            // reading local file as buffer
            const lfContentBuf = fs.readFileSync(localFile);
            commandParameters.response.progress.endBar();
            // retrieving the data-set to compare
            commandParameters.response.progress.startBar({ task });
            task.statusMessage = "Retrieving dataset";
            const dsContentBuf = yield zos_files_for_zowe_sdk_1.Get.dataSet(session, commandParameters.arguments.dataSetName, {
                binary: commandParameters.arguments.binary,
                encoding: commandParameters.arguments.encoding,
                record: commandParameters.arguments.record,
                volume: commandParameters.arguments.volumeSerial,
                responseTimeout: commandParameters.arguments.responseTimeout,
                task: task
            });
            const browserView = commandParameters.arguments.browserView;
            let lfContentString = "";
            let dsContentString = "";
            if (!commandParameters.arguments.seqnum) {
                const seqnumlen = 8;
                const lfStringArray = lfContentBuf.toString().split("\n");
                for (const i in lfStringArray) {
                    const sl = lfStringArray[i].length;
                    const tempString = lfStringArray[i].substring(0, sl - seqnumlen);
                    lfContentString += tempString + "\n";
                }
                const dsStringArray = dsContentBuf.toString().split("\n");
                for (const i in dsStringArray) {
                    const sl = dsStringArray[i].length;
                    const tempString = dsStringArray[i].substring(0, sl - seqnumlen);
                    dsContentString += tempString + "\n";
                }
            }
            else {
                lfContentString = lfContentBuf.toString();
                dsContentString = dsContentBuf.toString();
            }
            //  CHECHKING IIF THE BROWSER VIEW IS TRUE, OPEN UP THE DIFFS IN BROWSER
            if (browserView) {
                yield imperative_1.DiffUtils.openDiffInbrowser(lfContentString, dsContentString);
                return {
                    success: true,
                    commandResponse: "Launching local-file and data-set diffs in browser...",
                    apiResponse: {}
                };
            }
            let jsonDiff = "";
            const contextLinesArg = commandParameters.arguments.contextlines;
            jsonDiff = yield imperative_1.DiffUtils.getDiffString(lfContentString, dsContentString, {
                outputFormat: 'terminal',
                contextLinesArg: contextLinesArg
            });
            return {
                success: true,
                commandResponse: jsonDiff,
                apiResponse: {}
            };
        });
    }
}
exports.default = LocalfileDatasetHandler;
//# sourceMappingURL=LocalfileDataset.handler.js.map