"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require("fs");
const imperative_1 = require("@zowe/imperative");
const zos_jobs_for_zowe_sdk_1 = require("@zowe/zos-jobs-for-zowe-sdk");
const ZosFilesBase_handler_1 = require("../../ZosFilesBase.handler");
/**
 * Handler to compare spooldd's content
 * @export
 */
class LocalfileSpoolddHandler extends ZosFilesBase_handler_1.ZosFilesBaseHandler {
    processWithSession(commandParameters, session) {
        return __awaiter(this, void 0, void 0, function* () {
            const task = {
                percentComplete: 0,
                statusMessage: "Retrieving local file",
                stageName: imperative_1.TaskStage.IN_PROGRESS
            };
            const descriptionSeperator = ":";
            commandParameters.response.progress.startBar({ task });
            // retrieving local file
            let localFile;
            // resolving to full path if local path passed is not absolute
            if (path.isAbsolute(commandParameters.arguments.localFilePath)) {
                localFile = commandParameters.arguments.localFilePath;
            }
            else {
                localFile = path.resolve(commandParameters.arguments.localFilePath);
            }
            // check if the path given is of a file or not
            try {
                if (!fs.lstatSync(localFile).isFile()) {
                    throw new imperative_1.ImperativeError({
                        msg: 'Path given is not of a file, do recheck your path again'
                    });
                }
            }
            catch (error) {
                if (error instanceof imperative_1.ImperativeError)
                    throw error;
                throw new imperative_1.ImperativeError({
                    msg: 'Path not found. Please check the path and try again'
                });
            }
            const lfContentBuf = fs.readFileSync(localFile);
            let lfContentString = "";
            if (!commandParameters.arguments.seqnum) {
                const seqnumlen = 8;
                const lfStringArray = lfContentBuf.toString().split("\n");
                for (const i in lfStringArray) {
                    const sl = lfStringArray[i].length;
                    const tempString = lfStringArray[i].substring(0, sl - seqnumlen);
                    lfContentString += tempString + "\n";
                }
            }
            else {
                lfContentString = lfContentBuf.toString();
            }
            commandParameters.response.progress.endBar();
            commandParameters.response.progress.startBar({ task });
            task.statusMessage = "Retrieving spooldd";
            // retrieving information for  spooldd
            const spoolDescription = commandParameters.arguments.spoolDescription;
            const spoolDescArr = spoolDescription.split(descriptionSeperator);
            const jobName = spoolDescArr[0];
            const jobId = spoolDescArr[1];
            const spoolId = Number(spoolDescArr[2]);
            const spoolContentString = yield zos_jobs_for_zowe_sdk_1.GetJobs.getSpoolContentById(session, jobName, jobId, spoolId);
            //  CHECHKING IIF THE BROWSER VIEW IS TRUE, OPEN UP THE DIFFS IN BROWSER
            if (commandParameters.arguments.browserView) {
                yield imperative_1.DiffUtils.openDiffInbrowser(lfContentString, spoolContentString);
                return {
                    success: true,
                    commandResponse: "Launching local-file and spool-dd diffs in browser...",
                    apiResponse: {}
                };
            }
            let jsonDiff = "";
            const contextLinesArg = commandParameters.arguments.contextlines;
            jsonDiff = yield imperative_1.DiffUtils.getDiffString(lfContentString, spoolContentString, {
                outputFormat: 'terminal',
                contextLinesArg: contextLinesArg
            });
            return {
                success: true,
                commandResponse: jsonDiff,
                apiResponse: {}
            };
        });
    }
}
exports.default = LocalfileSpoolddHandler;
//# sourceMappingURL=LocalfileSpooldd.handler.js.map