"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const zos_jobs_for_zowe_sdk_1 = require("@zowe/zos-jobs-for-zowe-sdk");
const ZosFilesBase_handler_1 = require("../../ZosFilesBase.handler");
/**
 * Handler to compare spooldd's content
 * @export
 */
class SpoolddHandler extends ZosFilesBase_handler_1.ZosFilesBaseHandler {
    processWithSession(commandParameters, session) {
        return __awaiter(this, void 0, void 0, function* () {
            const task = {
                percentComplete: 0,
                statusMessage: "Retrieving first spool dd",
                stageName: imperative_1.TaskStage.IN_PROGRESS
            };
            const descriptionSeperator = ":";
            commandParameters.response.progress.startBar({ task });
            const spoolDescription1 = commandParameters.arguments.spoolDescription1;
            // retrieving information for first spooldd
            const spoolDescArr1 = spoolDescription1.split(descriptionSeperator);
            const jobName1 = spoolDescArr1[0];
            const jobId1 = spoolDescArr1[1];
            const spoolId1 = Number(spoolDescArr1[2]);
            const spoolContentString1 = yield zos_jobs_for_zowe_sdk_1.GetJobs.getSpoolContentById(session, jobName1, jobId1, spoolId1);
            commandParameters.response.progress.endBar();
            commandParameters.response.progress.startBar({ task });
            task.statusMessage = "Retrieving second spooldd";
            // retrieving information for second spooldd
            const spoolDescription2 = commandParameters.arguments.spoolDescription2;
            const spoolDescArr2 = spoolDescription2.split(descriptionSeperator);
            const jobName2 = spoolDescArr2[0];
            const jobId2 = spoolDescArr2[1];
            const spoolId2 = Number(spoolDescArr2[2]);
            const spoolContentString2 = yield zos_jobs_for_zowe_sdk_1.GetJobs.getSpoolContentById(session, jobName2, jobId2, spoolId2);
            //  CHECHKING IIF THE BROWSER VIEW IS TRUE, OPEN UP THE DIFFS IN BROWSER
            if (commandParameters.arguments.browserView) {
                yield imperative_1.DiffUtils.openDiffInbrowser(spoolContentString1, spoolContentString2);
                return {
                    success: true,
                    commandResponse: "Launching spool-dds' diffs in browser...",
                    apiResponse: {}
                };
            }
            let jsonDiff = "";
            const contextLinesArg = commandParameters.arguments.contextlines;
            jsonDiff = yield imperative_1.DiffUtils.getDiffString(spoolContentString1, spoolContentString2, {
                outputFormat: 'terminal',
                contextLinesArg: contextLinesArg
            });
            return {
                success: true,
                commandResponse: jsonDiff,
                apiResponse: {}
            };
        });
    }
}
exports.default = SpoolddHandler;
//# sourceMappingURL=Spooldd.handler.js.map