"use strict";
/*
* This program and the accompanying materials are made available under the terms of the
* Eclipse Public License v2.0 which accompanies this distribution, and is available at
* https://www.eclipse.org/legal/epl-v20.html
*
* SPDX-License-Identifier: EPL-2.0
*
* Copyright Contributors to the Zowe Project.
*
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const zos_files_for_zowe_sdk_1 = require("@zowe/zos-files-for-zowe-sdk");
const ZosFilesBase_handler_1 = require("../../ZosFilesBase.handler");
/**
 * Handler to view a data set's content
 * @export
 */
class UssFileHandler extends ZosFilesBase_handler_1.ZosFilesBaseHandler {
    processWithSession(commandParameters, session) {
        return __awaiter(this, void 0, void 0, function* () {
            const task = {
                percentComplete: 0,
                statusMessage: "Retrieving first uss file",
                stageName: imperative_1.TaskStage.IN_PROGRESS
            };
            commandParameters.response.progress.startBar({ task });
            const ussFileContentBuf1 = yield zos_files_for_zowe_sdk_1.Get.USSFile(session, commandParameters.arguments.ussFilePath1, {
                binary: commandParameters.arguments.binary,
                encoding: commandParameters.arguments.encoding,
                responseTimeout: commandParameters.arguments.responseTimeout,
                task: task
            });
            commandParameters.response.progress.endBar();
            commandParameters.response.progress.startBar({ task });
            let binary2 = commandParameters.arguments.binary2;
            let encoding2 = commandParameters.arguments.encoding2;
            const browserView = commandParameters.arguments.browserView;
            if (binary2 == undefined) {
                binary2 = commandParameters.arguments.binary;
            }
            if (encoding2 == undefined) {
                encoding2 = commandParameters.arguments.encoding;
            }
            task.statusMessage = "Retrieving second uss-file";
            const ussFileContentBuf2 = yield zos_files_for_zowe_sdk_1.Get.USSFile(session, commandParameters.arguments.ussFilePath2, {
                binary: binary2,
                encoding: encoding2,
                responseTimeout: commandParameters.arguments.responseTimeout,
                task: task
            });
            let ussContentString1 = "";
            let ussContentString2 = "";
            if (!commandParameters.arguments.seqnum) {
                const seqnumlen = 8;
                const ussFileStringArray1 = ussFileContentBuf1.toString().split("\n");
                for (const i in ussFileStringArray1) {
                    const sl = ussFileStringArray1[i].length;
                    const tempString = ussFileStringArray1[i].substring(0, sl - seqnumlen);
                    ussContentString1 += tempString + "\n";
                }
                const ussFileStringArray2 = ussFileContentBuf2.toString().split("\n");
                for (const i in ussFileStringArray2) {
                    const sl = ussFileStringArray2[i].length;
                    const tempString = ussFileStringArray2[i].substring(0, sl - seqnumlen);
                    ussContentString2 += tempString + "\n";
                }
            }
            else {
                ussContentString1 = ussFileContentBuf1.toString();
                ussContentString2 = ussFileContentBuf2.toString();
            }
            //  CHECHKING IsetsF THE BROWSER VIEW IS TRUE, OPEN UP THE DIFFS IN BROWSER
            if (browserView) {
                yield imperative_1.DiffUtils.openDiffInbrowser(ussContentString1, ussContentString2);
                return {
                    success: true,
                    commandResponse: "Launching uss files diffs in browser...",
                    apiResponse: {}
                };
            }
            let jsonDiff = "";
            const contextLinesArg = commandParameters.arguments.contextlines;
            jsonDiff = yield imperative_1.DiffUtils.getDiffString(ussContentString1, ussContentString2, {
                outputFormat: 'terminal',
                contextLinesArg: contextLinesArg
            });
            return {
                success: true,
                commandResponse: jsonDiff,
                apiResponse: {}
            };
        });
    }
}
exports.default = UssFileHandler;
//# sourceMappingURL=UssFile.handler.js.map